# -*- coding: utf-8 -*-
from django.conf.urls import patterns, url
from django.views.decorators.cache import cache_page
from django_placeholdit import settings
from django_placeholdit.views import PlaceholderView


placeholder = cache_page(settings.PLACEHOLDIT_CACHE_SECONDS)(PlaceholderView.as_view())


kwargs = {
    'width':      r'(?P<width>\d+)',
    'height':     r'(?P<height>\d+)',
    'format':     r'(?P<format>gif|jpe?g|png)',
    'background': r'(?P<background>.*?)',
    'color':      r'(?P<color>.*?)',
    'text':       r'(?P<text>.*?)',
}


urlpatterns = patterns(
    '',
    url(r'^/{width}(?:x{height})?(?:\.{format})?(?:/{background}(?:/{color})?)?(?:&text={text})?$'.format(**kwargs), placeholder, name='placeholder'),
)



# -*- coding: utf-8 -*-
from django.http import HttpResponse
from django.views.generic import View
from wand.color import Color
from wand.drawing import Drawing
from wand.image import Image


class PlaceholderView(View):
    def get(self, request, width, height, background, color, text, format):
        width = int(width)
        height = int(height or width)
        background = Color('#{}'.format(background or 'ccc'))
        color = Color('#{}'.format(color or '969696'))
        text = text or '{} x {}'.format(width, height)
        format = format or 'gif'

        with Image(width=width, height=height, background=background) as image:
            with Drawing() as draw:
                draw.fill_color = color
                draw.font_size = width / 2
                draw.text_alignment = 'center'
                draw.text_encoding = 'UTF-8'

                while True:
                    metrics = draw.get_font_metrics(image, text)

                    if metrics.text_width < width / 2:
                        break

                    draw.font_size -= 1

                draw.text(int(width / 2), int(height / 2 + (metrics.text_height - metrics.ascender - metrics.descender) / 2), text)
                draw(image)

            return HttpResponse(image.make_blob(format), content_type='image/{}'.format(format))



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

setup(
    name='django-placeholdit',
    version='1.0.2',
    description='A fully featured drop-in replacement of placehold.it for Django',
    long_description=open('README.rst').read(),
    keywords='django placeholder placehold.it',
    license=open('LICENSE').read(),
    author='Steve Lacey',
    author_email='steve@stevelacey.net',
    url='https://github.com/stevelacey/django-placeholdit',
    packages=['django_placeholdit'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Framework :: Django',
    ]
)
